import React, { useState } from 'react';
import './AddTeam.css';

const AddTeam = () => {
	const [date, setDate] = useState('');
	const [aTeamCount, setATeamCount] = useState(0);
	const [bTeamCount, setBTeamCount] = useState(0);
	const [teamImage, setTeamImage] = useState(''); // 團隊圖片的URL
	const [imageError, setImageError] = useState(false); // 圖片加載錯誤狀態

	// 設置 A 隊伍人數
	const handleATeamCountChange = (e: React.ChangeEvent<HTMLInputElement>) => {
		setATeamCount(parseInt(e.target.value) || 0);
	};

	// 設置 B 隊伍人數
	const handleBTeamCountChange = (e: React.ChangeEvent<HTMLInputElement>) => {
		setBTeamCount(parseInt(e.target.value) || 0);
	};

	const handleSubmit = () => {
		// 處理提交邏輯
		console.log('日期:', date);
		console.log('A隊伍人數:', aTeamCount);
		console.log('B隊伍人數:', bTeamCount);
		setTeamImage("")
	};

	const handleImageError = () => {
		setImageError(true); // 如果圖片加載失敗，設定錯誤狀態為 true
	};

	return (
		<div className="add-team-container">
			<h2>新增隊伍</h2>
			<form>
				<label>
					日期:
					<input
						type="text"
						value={date}
						onChange={(e) => setDate(e.target.value)}
					/>
				</label>
				<div className="teams-container">
					<div className="team-section">
						<h3>A隊伍</h3>
						<label>
							人數:
							<input
								type="number"
								value={aTeamCount}
								onChange={handleATeamCountChange}
							/>
						</label>
						{Array.from({ length: aTeamCount }, (_, index) => (
							<label key={`a-${index}`}>
								成員 {index + 1}:
								<input type="text" name={`aMember${index}`} />
							</label>
						))}
					</div>
					<div className="team-section">
						<h3>B隊伍</h3>
						<label>
							人數:
							<input
								type="number"
								value={bTeamCount}
								onChange={handleBTeamCountChange}
							/>
						</label>
						{Array.from({ length: bTeamCount }, (_, index) => (
							<label key={`b-${index}`}>
								成員 {index + 1}:
								<input type="text" name={`bMember${index}`} />
							</label>
						))}
					</div>
				</div>
				<button type="button" onClick={handleSubmit}>
					提交
				</button>
			</form>

			{/* 團隊圖片 */}
			{!imageError && (
				<div className="team-image-container">
					<img
						src={teamImage}
						alt="隊伍圖片"
						className="team-image"
						onError={handleImageError}
					/>
				</div>
			)}
		</div>
	);
};

export default AddTeam;
